@@ -4,16 +4,18 @@ package Dist::Zilla::Plugin::PodSpellingTests;
 # ABSTRACT: (DEPRECATED) The old name of the PodSpelling plugin
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '2.007003';
+our $VERSION = '2.007004';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::Test::PodSpelling';
 
-before register_component => sub {
-    warnings::warnif('deprecated',
-        "!!! [PodSpellingTests] is deprecated and will be removed in a future release; replace it with [Test::PodSpelling]\n",
-    );
-};
+# use warnings categories from the caller, not these modules
+use Carp ();
+local $Carp::Internal{'Class::Load'} = 1;
+local $Carp::Internal{'Module::Runtime'} = 1;
+warnings::warnif('deprecated',
+    '!!! [PodSpellingTests] is deprecated and will be removed in a future release; replace it with [Test::PodSpelling]',
+);
 
 no Moose;
 __PACKAGE__->meta->make_immutable;
@@ -31,7 +33,7 @@ Dist::Zilla::Plugin::PodSpellingTests - (DEPRECATED) The old name of the PodSpel
 
 =head1 VERSION
 
-version 2.007003
+version 2.007004
 
 =head1 SYNOPSIS
 
